/**
 * @file
 * JS extensions for comment_plus_js module.
 */

// Create our own namespace and specialized functions.
Drupal.commentPlusJs = {

  /**
   * Make an Ajax request to the module callbacks.
   *
   * @param caller
   */
  ajaxRequest: function(caller) {
    var cid = Drupal.commentPlusJs.extractId(caller, 'cid');
    var url = Drupal.settings.commentPlusJs.callbackPath + Drupal.commentPlusJs.extractId(caller, 'nid') + '/' + cid;
    $.ajax({
      type: 'POST',
      dataType: 'json',
      url: Drupal.settings.basePath + url,
      success: function(data) {
        Drupal.commentPlusJs.updateForm(cid, data);
      }
    });
  },

  /**
   * Extract the nid/cid from a link's CSS class.
   */
  extractId: function(caller, type) {
    var ret = '';
    var regex = new RegExp('\\breply-' + type + '-([0-9]+)');
    var ids = caller.attr('class').match(regex);
    if (ids) {
      ret = ids[1];
    }
    return ret;
  },

  /**
   * Change form data on successful Ajax operation.
   *
   * This callback processes instant reply results.
   * It changes the comment form's subject and body to the data
   * retrieved from the server callback.
   *
   * It also changes the form's "referer" field which will help
   * to properly indicate which content the new comment refers to.
   * This is important as the comment form, when residing on the node page
   * below the node and it's comments, by default considers comments always
   * referring to the node itself whyle the user may have clicked "reply to
   * comment".
   */
  updateForm: function(cid, data) {
    if (data) {
      if (data.subject != '') {
        $('input#edit-subject').val(data.subject);
      }
      $('textarea#edit-comment').val(data.content).scrollTop(
        $("textarea#edit-comment").attr("scrollHeight")
      ).focus();
    }
    $('input#edit-pid').val(cid);
  }
}

Drupal.behaviors.commentPlusJs = function(context) {

  // Create dynamic links and attach events. This all will only work
  // if we have the comment form residing on the same page, of course.
  if ($('form#comment-form').length > 0) {

    // Instant reply links.
    if (Drupal.settings.commentPlusJs.instantReplies) {
      $("a.comment-plus-js.reply", context).each(function() {
        $(this).click(function(event) {
          $('p#comment-form-replacement').hide();
          $('form#comment-form').show();
          Drupal.commentPlusJs.ajaxRequest($(this));
          event.preventDefault();
        });
      });
    }

    // Hide form if configured.
    if (Drupal.settings.commentPlusJs.hideForm) {
      $('form#comment-form', context).hide().before(
        '<p id="comment-form-replacement">' + Drupal.settings.commentPlusJs.formReplacementText + '</p>'
      );
    }
  }
}
